@@ -9,11 +9,11 @@ Cairo::CuttingLine - draw cutting line to cairo surface
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -24,9 +24,14 @@ to use Cairo::CuttingLine to render cutting lines to a canvas:
 
 we need to provide L<Cairo::Context> for L<Cairo::CuttingLine> method new.
 
+    my $surf = Cairo::ImageSurface->create ('argb32', 200 , 200 );
+    my $cr = Cairo::Context->create ($surf);
+
+set Cairo::Context object
+
     my $page = Cairo::CuttingLine->new( $cr );
 
-or set Cairo::Context object by cr accessor
+or by cr accessor
 
     $page->cr( $cr );
 
@@ -37,6 +42,16 @@ or set Cairo::Context object by cr accessor
     $page->color( 1, 1, 1, 1 );    # for set_source_rgba
     $page->stroke();
 
+=head1 DESCRIPTION
+
+Cairo::CuttingLine draws cutting line like this:
+
+    |       |
+   -+       +-
+      IMAGE
+   -+       +-
+    |       |
+
 =head1 FUNCTIONS
 
 =cut
@@ -58,7 +73,7 @@ sub cr {
 sub set {
     my $self = shift;
     $self->{p} = { @_ } if @_;
-    $self->{p};
+    return $self->{p};
 }
 
 sub length {
@@ -87,17 +102,22 @@ sub line_width {
 
 sub stroke {
     my $self = shift;
-
     my $cr = $self->{cr};
     $cr->save;
-    $cr->set_source_rgba( @{ $self->{color} } );
+
+    my $color = $self->{color};
+    $color ||= [1,1,1,1];
+
+    $cr->set_source_rgba( @$color );
     $cr->set_line_width( $self->line_width );
-    my $p = $self->set;
+    my $pos = $self->set;
+
     my $s = $self->size;
     my $line_len = $self->length;
 
     for my $p ( 0 .. 3 ) {
-        my ( $c_x, $c_y ) = ( $p->{x}, $p->{y} );
+
+        my ( $c_x, $c_y ) = ( $pos->{x}, $pos->{y} );
         if( $p & 1 ) {
             $c_x += $s->{width};
         }
